@@ -25,7 +25,7 @@ class Parser(bs4.BeautifulSoup, ABC):
         Returns:
 
         """
-        util.save_to_file(self.encode(), self.url)
+        util.save_to_file(self.encode(), self.url, filename=file_path)
 
 
     def generate_filename(self):
@@ -41,6 +41,8 @@ class Parser(bs4.BeautifulSoup, ABC):
             for key_prop in key_props:
                 try:
                     k = meta.attrs[key_prop]
+                    if isinstance(k, (list,set)):
+                        k = k[0]
                     if not k:
                         continue
                     retval[k] = {}
